@@ -19,6 +19,7 @@ field %policy = (
   SafeSitesFilterBehavior => 1 ,
 );
 
+
 method set_strict_policy ( $name = 'strict.json' , $type = 'managed' ) {
   my $json = JSON::PP -> new -> pretty( true );
   my $policy = $json -> encode( \%policy );
@@ -43,7 +44,21 @@ Chrome::Policy::Strict - Chrome strict policy role
 
 =head1 VERSION
 
-version 0.230360
+version 0.230410
+
+=head1 METHODS
+
+=head2 set_strict_policy([$name, $type])
+
+Apply strict policy set using Chrome policies below:
+
+  ForceGoogleSafeSearch: true
+  ForceYouTubeRestrict: 1
+  SafeSitesFilterBehavior: 1
+
+C<$name> is policy file name (F<strict.json> by default)
+
+C<$type> is "managed" by default, but may also be "recommended" as per the policy specification
 
 =head1 AUTHOR
 
